@@ -123,15 +123,16 @@ void loadConfig() {
     }
 
     if (tileProvider != NULL) {
-        GList *tileProvider = tileProviders;
+        GList *provider = tileProviders;
 
-        while (tileProvider != NULL) {
-            TileProvider *data = tileProvider -> data;
+        while (provider != NULL) {
+            TileProvider *data = provider -> data;
             if (g_str_equal(data -> name, tileProvider)) {
                 canvas.provider = data;
+
                 break;
             }
-            tileProvider = tileProvider -> next;
+            provider = provider -> next;
         }
     }
     if (canvas.provider == NULL) {
