@@ -19,6 +19,11 @@
 #include "tileengine.h"
 #include "console.h"
 
+
+//http://maps.googleapis.com/maps/api/geocode/xml?address=krakow,wybickiego%2014&sensor=true
+//http://maps.googleapis.com/maps/api/geocode/xml?latlng=52.40590109606264,16.92497491836548&sensor=true
+
+
 #define CLOUDMADE_QUERY_URL "http://geocoding.cloudmade.com/e4b1777b4b5154d69dbfc4678216183a/geocoding/v2/find.js?query=%s&return_location=true"
 #define QUERY_TMP_FILENAME "/tmp/cloudgps-query-tmp.js"
 
@@ -73,21 +78,28 @@ void readWorldCoordinate(json_object * jobj, WorldCoordinate *wc) {
 //             properties ->
 //                            name
 //                            is_in
-int geocode(char* query) {
-    // TODO encode query, ie spaces for '+', any special characters?
+
+typedef enum {
+	NO_QUERY, QUERY_IN_PROGRESS, DOWNLOAD_ERROR, PARSE_ERROR, ZERO_RESULTS, RESULTS_READY
+} SearchResultStatus;
+
+volatile SearchResultStatus searchResultsStatus = NO_QUERY;
+GList* results;
+// Download and prepare search results.
+int geocodeBgThread(void* query) {
     char *url, *json_string, *tmp;
     int i;
     size_t length;
 
-    tmp = url_encode(query);
+    tmp = url_encode((char*) query);
+    free(query);
 
     if (asprintf(&url, CLOUDMADE_QUERY_URL, tmp) < 0) {
     	fprintf(stderr, "asprintf failed in geocode\n");
-    	return FALSE;
+    	return 0;
     }
 	fprintf(stderr, "Search URL: %s\n", url);
     free(tmp);
-    GList *results = NULL;
 
     if (downloadAndSave(url, QUERY_TMP_FILENAME)) {
         if (g_file_get_contents(QUERY_TMP_FILENAME, &json_string, &length, NULL)) {
@@ -110,26 +122,60 @@ int geocode(char* query) {
 //                    fprintf(stderr, "Name: '%s' Description: '%s', center: %f, %f, Wikipedia: '%s'\n", result -> name, result -> description, result -> centroid.latitude, result -> centroid.longitude, result-> wikipedia == NULL ? "null": result -> wikipedia);
                     results = g_list_append(results, result);
                 }
-				sprintf(buf, "Search query: %d results", length);
-				addConsoleLine(buf, 0, 1, 0);
+                searchResultsStatus = RESULTS_READY;
+            	return 0;
             } else {
-				sprintf(buf, "Search query: no results");
-				addConsoleLine(buf, 0, 1, 0);
+            	searchResultsStatus = ZERO_RESULTS;
+            	return 0;
             }
 
             g_free(json_string);
 
-            tileEngineProcessSearchResults(results);
-
-            g_list_free(results);
-
-            return TRUE;
+			searchResultsStatus = PARSE_ERROR;
         } else {
-			sprintf(buf, "Search error");
-			addConsoleLine(buf, 1, 0, 0);
+			searchResultsStatus = DOWNLOAD_ERROR;
             fprintf(stderr, "Unable to read query results from %s\n", QUERY_TMP_FILENAME);
-            return FALSE;
         }
     }
-    return FALSE;
+    searchResultsStatus ;
+    return 0;
+}
+
+void spawnQueryThread(char* query) {
+	if (searchResultsStatus != NO_QUERY) {
+		sprintf(buf, "Search query: thread busy - try again");
+		addConsoleLine(buf, 1, 1, 0);
+	} else {
+		char* copy = malloc(SEARCHBAR_MAX_CHARS);
+		strncpy(copy, query, SEARCHBAR_MAX_CHARS);
+		SDL_CreateThread(geocodeBgThread, (void*) copy);
+	}
+}
+
+void processGeocoding() {
+	switch (searchResultsStatus) {
+	case NO_QUERY:
+	case QUERY_IN_PROGRESS:
+		break;
+	case DOWNLOAD_ERROR:
+		sprintf(buf, "Search download error");
+		addConsoleLine(buf, 1, 0, 0);
+		break;
+	case PARSE_ERROR:
+		sprintf(buf, "Search parse error");
+		addConsoleLine(buf, 1, 0, 0);
+		break;
+	case ZERO_RESULTS:
+		sprintf(buf, "Search query: no results");
+		addConsoleLine(buf, 0, 1, 0);
+		break;
+	case RESULTS_READY:
+		sprintf(buf, "Search query: %d results", g_list_length(results));
+		addConsoleLine(buf, 0, 1, 0);
+	    tileEngineProcessSearchResults(results);
+		g_list_free(results);
+		results = NULL;
+		break;
+	}
+	searchResultsStatus = NO_QUERY;
 }
