@@ -21,8 +21,7 @@
 
 #include "../main.h"
 
-#define GOOGLE_QUERY_URL "http://maps.googleapis.com/maps/api/geocode/json?address=%s&sensor=true"
-
+char* google_prepare_url(char* encodedQuery);
 void google_parse_response(char* response);
 
 #endif /* GOOGLE_GEOCODER_H_ */
