@@ -107,10 +107,36 @@ SDL_Surface* loadTextureFromFile(char *filename, t_tile* tile,
 	return NULL;
 }
 
+GHashTable* textureSizeHashTable = NULL;
+
+volatile long allocatedTexturesSize = 0;
+
+void deleteTexture(GLuint texture) {
+	int textureSize = (int) g_hash_table_lookup(textureSizeHashTable, texture);
+//	fprintf(stderr, "delete texture %d, size = %d, allocated total = %ld\n", texture, textureSize, allocatedTexturesSize);
+	glDeleteTextures(1, &texture);
+	allocatedTexturesSize -= textureSize;
+}
+
 GLuint createTexture(const GLushort * pixels4444, int w, int h, int isTile) {
 	GLuint texture;
 
+	if (textureSizeHashTable == NULL) {
+		textureSizeHashTable = g_hash_table_new(NULL, NULL);
+		if (textureSizeHashTable == NULL) {
+			fprintf(stderr, "texture size hash table creation error\n");
+			exit(1);
+		}
+	}
+
 	glGenTextures(1, &texture);
+
+	if (isTile) {
+		g_hash_table_insert(textureSizeHashTable, texture, w*h*2);
+		allocatedTexturesSize += w*h*2;
+//		fprintf(stderr, "create texture %d, size = %d, allocated total = %ld\n", texture, w*h*2, allocatedTexturesSize);
+	}
+
 	glBindTexture(GL_TEXTURE_2D, texture);
 
 	glTexParameteri(GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_TRUE);
