@@ -50,7 +50,7 @@ void setZoomBarInitialized(int value);
 void tileEngineProcessAccelerometer();
 void toWorldCoordinate(TileCoordinate* tc, WorldCoordinate* result);
 void toTileCoordinate(WorldCoordinate* wc, TileCoordinate* result, int zoom);
-void toScreenCoordinate(TileCoordinate *tc, GLfloat *x, GLfloat *y);
+void toScreenCoordinate(TileCoordinate *tc, Point* p);
 void canvasCenterToTileCoordinate(TileCoordinate* tc);
 double getDistance(WorldCoordinate* c1, WorldCoordinate* c2);
 GLfloat getMarkerRotation();
